/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { Certification } from "../../components/cert";
import { Rule } from "../../components/rule";
import { Certifications } from "../../config/Certifications";
import type { JSX } from "react";

/**
 * Renders the /certs page.
 * @returns A React Component.
 */
const Certs = (): JSX.Element => {
  return (
    <main className="w-[95%] text-center
      max-w-4xl m-auto mt-16 mb-16 rounded-lg">
      <h1 className="text-5xl">{`Certs`}</h1>
      <section>
        <p className="mb-2">
          {`This page lists the professional certifications Naomi has obtained
          throughout her time as a developer.`}
        </p>
        <Rule />
        <div className="grid sm:grid-cols-2 lg:grid-cols-3 grid-cols-1 gap-y-5">
          {Certifications.toSorted(
            (a, b) => {
              return b.date.getTime() - a.date.getTime();
            },
          ).map((cert) => {
            return <Certification
              date={cert.date}
              fileName={cert.fileName}
              issuer={cert.issuer}
              key={cert.name}
              name={cert.name}
            />;
          })}
        </div>
      </section>
    </main>
  );
};

export default Certs;
