/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { KoikatsuComponent } from "../../components/koikatsu";
import { Rule } from "../../components/rule";
import { Koikatsu } from "../../config/Koikatsu";
import type { JSX } from "react";

/**
 * Renders the /games page.
 * @returns A React Component.
 */
const KoikatsuPage = (): JSX.Element => {
  return (
    <main
      className="w-[95%] text-center
      max-w-4xl m-auto mt-16 mb-16 rounded-lg"
    >
      <h1 className="text-5xl">{`Koikatsu`}</h1>
      <section>
        <p className="mb-2">{`Images of Naomi generated in Koikatsu. Note that the list of images is dynamically generated, so we aren't able to provide alt text for these.`}</p>
        <Rule />
        <div className="grid sm:grid-cols-2 lg:grid-cols-3 grid-cols-1 gap-y-5">
          {Koikatsu.toSorted((a, b) => {
            return a.localeCompare(b);
          }).map((img) => {
            return (
              <KoikatsuComponent img={img} key={img} />
            );
          })}
        </div>
      </section>
    </main>
  );
};

export default KoikatsuPage;
