/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

/**
 * Renders the view for a koikatsu shot.
 * @param props - An object containing the image file name.
 * @param props.img - The file name of the image to render.
 * @returns A JSX element.
 */
export const KoikatsuComponent = ({ img }: { readonly img: string }):
JSX.Element => {
  return (
    <div className="w-[300px] border-2
    border-solid border-[--foreground] m-auto text-center items-center">
      <a
        href={`https://cdn.nhcarrigan.com/koikatsu/${img}`}
        rel="noreferrer"
        target="_blank"
      >
        <Image
          alt="This work is solely decorative. If you'd like alt text,
            please reach out in our Discord and we'll be happy to provide it."
          className="m-auto object-cover"
          height={300}
          src={`https://cdn.nhcarrigan.com/koikatsu/${img}`}
          width={300}
        />
      </a>
    </div>
  );
};
